@@ -1,6 +1,10 @@
 <?php
 
+use Illuminate\Contracts\Debug\ExceptionHandler;
+use Illuminate\Contracts\Validation\Factory;
+use Illuminate\Http\Response;
 use Laravel\Lumen\Application;
+use Laravel\Lumen\Console\ConsoleServiceProvider;
 use Laravel\Lumen\Http\Request;
 use Mockery as m;
 use PHPUnit\Framework\TestCase;
@@ -26,7 +30,7 @@ class FullApplicationTest extends TestCase
         $this->assertEquals(200, $response->getStatusCode());
         $this->assertEquals('Hello World', $response->getContent());
 
-        $this->assertInstanceOf('Illuminate\Http\Request', $request);
+        $this->assertInstanceOf(Request::class, $request);
     }
 
     public function testBasicSymfonyRequest()
@@ -230,7 +234,7 @@ class FullApplicationTest extends TestCase
     public function testNotFoundResponse()
     {
         $app = new Application;
-        $app->instance('Illuminate\Contracts\Debug\ExceptionHandler', $mock = m::mock('Laravel\Lumen\Exceptions\Handler[report]'));
+        $app->instance(ExceptionHandler::class, $mock = m::mock('Laravel\Lumen\Exceptions\Handler[report]'));
         $mock->shouldIgnoreMissing();
 
         $app->router->get('/', function () {
@@ -245,7 +249,7 @@ class FullApplicationTest extends TestCase
     public function testMethodNotAllowedResponse()
     {
         $app = new Application;
-        $app->instance('Illuminate\Contracts\Debug\ExceptionHandler', $mock = m::mock('Laravel\Lumen\Exceptions\Handler[report]'));
+        $app->instance(ExceptionHandler::class, $mock = m::mock('Laravel\Lumen\Exceptions\Handler[report]'));
         $mock->shouldIgnoreMissing();
 
         $app->router->post('/', function () {
@@ -275,7 +279,7 @@ class FullApplicationTest extends TestCase
     public function testUncaughtExceptionResponse()
     {
         $app = new Application;
-        $app->instance('Illuminate\Contracts\Debug\ExceptionHandler', $mock = m::mock('Laravel\Lumen\Exceptions\Handler[report]'));
+        $app->instance(ExceptionHandler::class, $mock = m::mock('Laravel\Lumen\Exceptions\Handler[report]'));
         $mock->shouldIgnoreMissing();
 
         $app->router->get('/', function () {
@@ -283,7 +287,7 @@ class FullApplicationTest extends TestCase
         });
 
         $response = $app->handle(Request::create('/', 'GET'));
-        $this->assertInstanceOf('Illuminate\Http\Response', $response);
+        $this->assertInstanceOf(Response::class, $response);
     }
 
     public function testGeneratingUrls()
@@ -379,7 +383,8 @@ class FullApplicationTest extends TestCase
     public function testApplicationBootsOnlyOnce()
     {
         $app = new Application();
-        $provider = new class($app) extends \Illuminate\Support\ServiceProvider {
+        $provider = new class($app) extends \Illuminate\Support\ServiceProvider
+        {
             public $bootCount = 0;
 
             public function boot()
@@ -623,9 +628,9 @@ class FullApplicationTest extends TestCase
     {
         $app = new Application();
 
-        $validator = $app['Illuminate\Contracts\Validation\Factory'];
+        $validator = $app[Factory::class];
 
-        $this->assertInstanceOf('Illuminate\Contracts\Validation\Factory', $validator);
+        $this->assertInstanceOf(Factory::class, $validator);
     }
 
     public function testCanMergeUserProvidedFacadesWithDefaultOnes()
@@ -754,6 +759,15 @@ class FullApplicationTest extends TestCase
         $app->handle(Request::create('/'));
         $this->assertTrue($rebound);
     }
+
+    public function testBatchesTableCommandIsRegistered()
+    {
+        $app = new LumenTestApplication();
+        $app->register(ConsoleServiceProvider::class);
+        $command = $app->make('command.queue.batches-table');
+        $this->assertNotNull($command);
+        $this->assertEquals('queue:batches-table', $command->getName());
+    }
 }
 
 class LumenTestService
@@ -816,7 +830,7 @@ class LumenTestPlainMiddleware
     public function handle($request, $next)
     {
         $response = $next($request);
-        $_SERVER['__middleware.response'] = $response instanceof Illuminate\Http\Response;
+        $_SERVER['__middleware.response'] = $response instanceof Response;
 
         return $response;
     }
@@ -857,7 +871,7 @@ class LumenTestTerminateMiddleware
         return $next($request);
     }
 
-    public function terminate($request, Illuminate\Http\Response $response)
+    public function terminate($request, Response $response)
     {
         $response->setContent('TERMINATED');
     }
